# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PoolStatsDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'add_asset_liquidity_volume': 'str',
        'add_liquidity_count': 'str',
        'add_liquidity_volume': 'str',
        'add_rune_liquidity_volume': 'str',
        'annual_percentage_rate': 'str',
        'asset': 'str',
        'asset_depth': 'str',
        'asset_price': 'str',
        'asset_price_usd': 'str',
        'average_slip': 'str',
        'earnings': 'str',
        'earnings_annual_as_percent_of_depth': 'str',
        'liquidity_units': 'str',
        'pool_apy': 'str',
        'rune_depth': 'str',
        'savers_apr': 'str',
        'status': 'str',
        'swap_count': 'str',
        'swap_volume': 'str',
        'synth_supply': 'str',
        'synth_units': 'str',
        'to_asset_average_slip': 'str',
        'to_asset_count': 'str',
        'to_asset_fees': 'str',
        'to_asset_volume': 'str',
        'to_rune_average_slip': 'str',
        'to_rune_count': 'str',
        'to_rune_fees': 'str',
        'to_rune_volume': 'str',
        'total_fees': 'str',
        'unique_member_count': 'str',
        'unique_swapper_count': 'str',
        'units': 'str',
        'withdraw_asset_volume': 'str',
        'withdraw_count': 'str',
        'withdraw_rune_volume': 'str',
        'withdraw_volume': 'str'
    }

    attribute_map = {
        'add_asset_liquidity_volume': 'addAssetLiquidityVolume',
        'add_liquidity_count': 'addLiquidityCount',
        'add_liquidity_volume': 'addLiquidityVolume',
        'add_rune_liquidity_volume': 'addRuneLiquidityVolume',
        'annual_percentage_rate': 'annualPercentageRate',
        'asset': 'asset',
        'asset_depth': 'assetDepth',
        'asset_price': 'assetPrice',
        'asset_price_usd': 'assetPriceUSD',
        'average_slip': 'averageSlip',
        'earnings': 'earnings',
        'earnings_annual_as_percent_of_depth': 'earningsAnnualAsPercentOfDepth',
        'liquidity_units': 'liquidityUnits',
        'pool_apy': 'poolAPY',
        'rune_depth': 'runeDepth',
        'savers_apr': 'saversAPR',
        'status': 'status',
        'swap_count': 'swapCount',
        'swap_volume': 'swapVolume',
        'synth_supply': 'synthSupply',
        'synth_units': 'synthUnits',
        'to_asset_average_slip': 'toAssetAverageSlip',
        'to_asset_count': 'toAssetCount',
        'to_asset_fees': 'toAssetFees',
        'to_asset_volume': 'toAssetVolume',
        'to_rune_average_slip': 'toRuneAverageSlip',
        'to_rune_count': 'toRuneCount',
        'to_rune_fees': 'toRuneFees',
        'to_rune_volume': 'toRuneVolume',
        'total_fees': 'totalFees',
        'unique_member_count': 'uniqueMemberCount',
        'unique_swapper_count': 'uniqueSwapperCount',
        'units': 'units',
        'withdraw_asset_volume': 'withdrawAssetVolume',
        'withdraw_count': 'withdrawCount',
        'withdraw_rune_volume': 'withdrawRuneVolume',
        'withdraw_volume': 'withdrawVolume'
    }

    def __init__(self, add_asset_liquidity_volume=None, add_liquidity_count=None, add_liquidity_volume=None, add_rune_liquidity_volume=None, annual_percentage_rate=None, asset=None, asset_depth=None, asset_price=None, asset_price_usd=None, average_slip=None, earnings=None, earnings_annual_as_percent_of_depth=None, liquidity_units=None, pool_apy=None, rune_depth=None, savers_apr=None, status=None, swap_count=None, swap_volume=None, synth_supply=None, synth_units=None, to_asset_average_slip=None, to_asset_count=None, to_asset_fees=None, to_asset_volume=None, to_rune_average_slip=None, to_rune_count=None, to_rune_fees=None, to_rune_volume=None, total_fees=None, unique_member_count=None, unique_swapper_count=None, units=None, withdraw_asset_volume=None, withdraw_count=None, withdraw_rune_volume=None, withdraw_volume=None):  # noqa: E501
        """PoolStatsDetail - a model defined in Swagger"""  # noqa: E501
        self._add_asset_liquidity_volume = None
        self._add_liquidity_count = None
        self._add_liquidity_volume = None
        self._add_rune_liquidity_volume = None
        self._annual_percentage_rate = None
        self._asset = None
        self._asset_depth = None
        self._asset_price = None
        self._asset_price_usd = None
        self._average_slip = None
        self._earnings = None
        self._earnings_annual_as_percent_of_depth = None
        self._liquidity_units = None
        self._pool_apy = None
        self._rune_depth = None
        self._savers_apr = None
        self._status = None
        self._swap_count = None
        self._swap_volume = None
        self._synth_supply = None
        self._synth_units = None
        self._to_asset_average_slip = None
        self._to_asset_count = None
        self._to_asset_fees = None
        self._to_asset_volume = None
        self._to_rune_average_slip = None
        self._to_rune_count = None
        self._to_rune_fees = None
        self._to_rune_volume = None
        self._total_fees = None
        self._unique_member_count = None
        self._unique_swapper_count = None
        self._units = None
        self._withdraw_asset_volume = None
        self._withdraw_count = None
        self._withdraw_rune_volume = None
        self._withdraw_volume = None
        self.discriminator = None
        self.add_asset_liquidity_volume = add_asset_liquidity_volume
        self.add_liquidity_count = add_liquidity_count
        self.add_liquidity_volume = add_liquidity_volume
        self.add_rune_liquidity_volume = add_rune_liquidity_volume
        self.annual_percentage_rate = annual_percentage_rate
        self.asset = asset
        self.asset_depth = asset_depth
        self.asset_price = asset_price
        self.asset_price_usd = asset_price_usd
        self.average_slip = average_slip
        self.earnings = earnings
        self.earnings_annual_as_percent_of_depth = earnings_annual_as_percent_of_depth
        self.liquidity_units = liquidity_units
        self.pool_apy = pool_apy
        self.rune_depth = rune_depth
        self.savers_apr = savers_apr
        self.status = status
        self.swap_count = swap_count
        self.swap_volume = swap_volume
        self.synth_supply = synth_supply
        self.synth_units = synth_units
        self.to_asset_average_slip = to_asset_average_slip
        self.to_asset_count = to_asset_count
        self.to_asset_fees = to_asset_fees
        self.to_asset_volume = to_asset_volume
        self.to_rune_average_slip = to_rune_average_slip
        self.to_rune_count = to_rune_count
        self.to_rune_fees = to_rune_fees
        self.to_rune_volume = to_rune_volume
        self.total_fees = total_fees
        self.unique_member_count = unique_member_count
        self.unique_swapper_count = unique_swapper_count
        self.units = units
        self.withdraw_asset_volume = withdraw_asset_volume
        self.withdraw_count = withdraw_count
        self.withdraw_rune_volume = withdraw_rune_volume
        self.withdraw_volume = withdraw_volume

    @property
    def add_asset_liquidity_volume(self):
        """Gets the add_asset_liquidity_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/liquidity_changes:addAssetLiquidityVolume  # noqa: E501

        :return: The add_asset_liquidity_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._add_asset_liquidity_volume

    @add_asset_liquidity_volume.setter
    def add_asset_liquidity_volume(self, add_asset_liquidity_volume):
        """Sets the add_asset_liquidity_volume of this PoolStatsDetail.

        Int64(e8), same as history/liquidity_changes:addAssetLiquidityVolume  # noqa: E501

        :param add_asset_liquidity_volume: The add_asset_liquidity_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if add_asset_liquidity_volume is None:
            raise ValueError("Invalid value for `add_asset_liquidity_volume`, must not be `None`")  # noqa: E501

        self._add_asset_liquidity_volume = add_asset_liquidity_volume

    @property
    def add_liquidity_count(self):
        """Gets the add_liquidity_count of this PoolStatsDetail.  # noqa: E501

        Int64, same as history/liquidity_changes:addLiquidityCount  # noqa: E501

        :return: The add_liquidity_count of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._add_liquidity_count

    @add_liquidity_count.setter
    def add_liquidity_count(self, add_liquidity_count):
        """Sets the add_liquidity_count of this PoolStatsDetail.

        Int64, same as history/liquidity_changes:addLiquidityCount  # noqa: E501

        :param add_liquidity_count: The add_liquidity_count of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if add_liquidity_count is None:
            raise ValueError("Invalid value for `add_liquidity_count`, must not be `None`")  # noqa: E501

        self._add_liquidity_count = add_liquidity_count

    @property
    def add_liquidity_volume(self):
        """Gets the add_liquidity_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/liquidity_changes:addLiquidityVolume  # noqa: E501

        :return: The add_liquidity_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._add_liquidity_volume

    @add_liquidity_volume.setter
    def add_liquidity_volume(self, add_liquidity_volume):
        """Sets the add_liquidity_volume of this PoolStatsDetail.

        Int64(e8), same as history/liquidity_changes:addLiquidityVolume  # noqa: E501

        :param add_liquidity_volume: The add_liquidity_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if add_liquidity_volume is None:
            raise ValueError("Invalid value for `add_liquidity_volume`, must not be `None`")  # noqa: E501

        self._add_liquidity_volume = add_liquidity_volume

    @property
    def add_rune_liquidity_volume(self):
        """Gets the add_rune_liquidity_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/liquidity_changes:addRuneLiquidityVolume  # noqa: E501

        :return: The add_rune_liquidity_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._add_rune_liquidity_volume

    @add_rune_liquidity_volume.setter
    def add_rune_liquidity_volume(self, add_rune_liquidity_volume):
        """Sets the add_rune_liquidity_volume of this PoolStatsDetail.

        Int64(e8), same as history/liquidity_changes:addRuneLiquidityVolume  # noqa: E501

        :param add_rune_liquidity_volume: The add_rune_liquidity_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if add_rune_liquidity_volume is None:
            raise ValueError("Invalid value for `add_rune_liquidity_volume`, must not be `None`")  # noqa: E501

        self._add_rune_liquidity_volume = add_rune_liquidity_volume

    @property
    def annual_percentage_rate(self):
        """Gets the annual_percentage_rate of this PoolStatsDetail.  # noqa: E501

        deprecated now it's only showing zero util being deleted.  # noqa: E501

        :return: The annual_percentage_rate of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._annual_percentage_rate

    @annual_percentage_rate.setter
    def annual_percentage_rate(self, annual_percentage_rate):
        """Sets the annual_percentage_rate of this PoolStatsDetail.

        deprecated now it's only showing zero util being deleted.  # noqa: E501

        :param annual_percentage_rate: The annual_percentage_rate of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if annual_percentage_rate is None:
            raise ValueError("Invalid value for `annual_percentage_rate`, must not be `None`")  # noqa: E501

        self._annual_percentage_rate = annual_percentage_rate

    @property
    def asset(self):
        """Gets the asset of this PoolStatsDetail.  # noqa: E501


        :return: The asset of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this PoolStatsDetail.


        :param asset: The asset of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def asset_depth(self):
        """Gets the asset_depth of this PoolStatsDetail.  # noqa: E501

        Int64(e8), the amount of Asset in the pool  # noqa: E501

        :return: The asset_depth of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset_depth

    @asset_depth.setter
    def asset_depth(self, asset_depth):
        """Sets the asset_depth of this PoolStatsDetail.

        Int64(e8), the amount of Asset in the pool  # noqa: E501

        :param asset_depth: The asset_depth of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if asset_depth is None:
            raise ValueError("Invalid value for `asset_depth`, must not be `None`")  # noqa: E501

        self._asset_depth = asset_depth

    @property
    def asset_price(self):
        """Gets the asset_price of this PoolStatsDetail.  # noqa: E501

        Float, price of asset in rune. I.e. rune amount / asset amount  # noqa: E501

        :return: The asset_price of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset_price

    @asset_price.setter
    def asset_price(self, asset_price):
        """Sets the asset_price of this PoolStatsDetail.

        Float, price of asset in rune. I.e. rune amount / asset amount  # noqa: E501

        :param asset_price: The asset_price of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if asset_price is None:
            raise ValueError("Invalid value for `asset_price`, must not be `None`")  # noqa: E501

        self._asset_price = asset_price

    @property
    def asset_price_usd(self):
        """Gets the asset_price_usd of this PoolStatsDetail.  # noqa: E501

        Float, the price of asset in USD (based on the deepest USD pool).  # noqa: E501

        :return: The asset_price_usd of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._asset_price_usd

    @asset_price_usd.setter
    def asset_price_usd(self, asset_price_usd):
        """Sets the asset_price_usd of this PoolStatsDetail.

        Float, the price of asset in USD (based on the deepest USD pool).  # noqa: E501

        :param asset_price_usd: The asset_price_usd of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if asset_price_usd is None:
            raise ValueError("Invalid value for `asset_price_usd`, must not be `None`")  # noqa: E501

        self._asset_price_usd = asset_price_usd

    @property
    def average_slip(self):
        """Gets the average_slip of this PoolStatsDetail.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), same as history/swaps:averageSlip   # noqa: E501

        :return: The average_slip of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._average_slip

    @average_slip.setter
    def average_slip(self, average_slip):
        """Sets the average_slip of this PoolStatsDetail.

        Float64 (Basis points, 0-10000, where 10000=100%), same as history/swaps:averageSlip   # noqa: E501

        :param average_slip: The average_slip of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if average_slip is None:
            raise ValueError("Invalid value for `average_slip`, must not be `None`")  # noqa: E501

        self._average_slip = average_slip

    @property
    def earnings(self):
        """Gets the earnings of this PoolStatsDetail.  # noqa: E501

        Int64(e8), The earning that has been recorded from the pool asset's Liquidity Fees and Rewards in RUNE. The earnings shown are from the period parameter default being 14 days  (configurable by the period parameter).   # noqa: E501

        :return: The earnings of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._earnings

    @earnings.setter
    def earnings(self, earnings):
        """Sets the earnings of this PoolStatsDetail.

        Int64(e8), The earning that has been recorded from the pool asset's Liquidity Fees and Rewards in RUNE. The earnings shown are from the period parameter default being 14 days  (configurable by the period parameter).   # noqa: E501

        :param earnings: The earnings of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if earnings is None:
            raise ValueError("Invalid value for `earnings`, must not be `None`")  # noqa: E501

        self._earnings = earnings

    @property
    def earnings_annual_as_percent_of_depth(self):
        """Gets the earnings_annual_as_percent_of_depth of this PoolStatsDetail.  # noqa: E501

        Float, The estimation of earnings during the time interval expanded through a year  compared to the current pool depth. E.g. 0.1 means the pool based on this interval earnings can earn 10% of its pool during a year.   # noqa: E501

        :return: The earnings_annual_as_percent_of_depth of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._earnings_annual_as_percent_of_depth

    @earnings_annual_as_percent_of_depth.setter
    def earnings_annual_as_percent_of_depth(self, earnings_annual_as_percent_of_depth):
        """Sets the earnings_annual_as_percent_of_depth of this PoolStatsDetail.

        Float, The estimation of earnings during the time interval expanded through a year  compared to the current pool depth. E.g. 0.1 means the pool based on this interval earnings can earn 10% of its pool during a year.   # noqa: E501

        :param earnings_annual_as_percent_of_depth: The earnings_annual_as_percent_of_depth of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if earnings_annual_as_percent_of_depth is None:
            raise ValueError("Invalid value for `earnings_annual_as_percent_of_depth`, must not be `None`")  # noqa: E501

        self._earnings_annual_as_percent_of_depth = earnings_annual_as_percent_of_depth

    @property
    def liquidity_units(self):
        """Gets the liquidity_units of this PoolStatsDetail.  # noqa: E501

        Int64, Liquidity Units in the pool  # noqa: E501

        :return: The liquidity_units of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_units

    @liquidity_units.setter
    def liquidity_units(self, liquidity_units):
        """Sets the liquidity_units of this PoolStatsDetail.

        Int64, Liquidity Units in the pool  # noqa: E501

        :param liquidity_units: The liquidity_units of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if liquidity_units is None:
            raise ValueError("Invalid value for `liquidity_units`, must not be `None`")  # noqa: E501

        self._liquidity_units = liquidity_units

    @property
    def pool_apy(self):
        """Gets the pool_apy of this PoolStatsDetail.  # noqa: E501

        deprecated now it's only showing zero util being deleted.  # noqa: E501

        :return: The pool_apy of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._pool_apy

    @pool_apy.setter
    def pool_apy(self, pool_apy):
        """Sets the pool_apy of this PoolStatsDetail.

        deprecated now it's only showing zero util being deleted.  # noqa: E501

        :param pool_apy: The pool_apy of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if pool_apy is None:
            raise ValueError("Invalid value for `pool_apy`, must not be `None`")  # noqa: E501

        self._pool_apy = pool_apy

    @property
    def rune_depth(self):
        """Gets the rune_depth of this PoolStatsDetail.  # noqa: E501

        Int64(e8), the amount of Rune in the pool  # noqa: E501

        :return: The rune_depth of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._rune_depth

    @rune_depth.setter
    def rune_depth(self, rune_depth):
        """Sets the rune_depth of this PoolStatsDetail.

        Int64(e8), the amount of Rune in the pool  # noqa: E501

        :param rune_depth: The rune_depth of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if rune_depth is None:
            raise ValueError("Invalid value for `rune_depth`, must not be `None`")  # noqa: E501

        self._rune_depth = rune_depth

    @property
    def savers_apr(self):
        """Gets the savers_apr of this PoolStatsDetail.  # noqa: E501

        Float, Annual Return estimated linearly (not compounded) for savers from a period of typically the last 30 or 100 days (configurable by the period parameter, default is 14). E.g. 0.1 means 10% yearly return. If the savers period has not yet been reached, It will show zero instead.   # noqa: E501

        :return: The savers_apr of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._savers_apr

    @savers_apr.setter
    def savers_apr(self, savers_apr):
        """Sets the savers_apr of this PoolStatsDetail.

        Float, Annual Return estimated linearly (not compounded) for savers from a period of typically the last 30 or 100 days (configurable by the period parameter, default is 14). E.g. 0.1 means 10% yearly return. If the savers period has not yet been reached, It will show zero instead.   # noqa: E501

        :param savers_apr: The savers_apr of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if savers_apr is None:
            raise ValueError("Invalid value for `savers_apr`, must not be `None`")  # noqa: E501

        self._savers_apr = savers_apr

    @property
    def status(self):
        """Gets the status of this PoolStatsDetail.  # noqa: E501

        The state of the pool, e.g. Available, Staged  # noqa: E501

        :return: The status of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PoolStatsDetail.

        The state of the pool, e.g. Available, Staged  # noqa: E501

        :param status: The status of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def swap_count(self):
        """Gets the swap_count of this PoolStatsDetail.  # noqa: E501

        Int64, same as history/swaps:totalCount  # noqa: E501

        :return: The swap_count of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._swap_count

    @swap_count.setter
    def swap_count(self, swap_count):
        """Sets the swap_count of this PoolStatsDetail.

        Int64, same as history/swaps:totalCount  # noqa: E501

        :param swap_count: The swap_count of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if swap_count is None:
            raise ValueError("Invalid value for `swap_count`, must not be `None`")  # noqa: E501

        self._swap_count = swap_count

    @property
    def swap_volume(self):
        """Gets the swap_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/swaps:totalVolume  # noqa: E501

        :return: The swap_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._swap_volume

    @swap_volume.setter
    def swap_volume(self, swap_volume):
        """Sets the swap_volume of this PoolStatsDetail.

        Int64(e8), same as history/swaps:totalVolume  # noqa: E501

        :param swap_volume: The swap_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if swap_volume is None:
            raise ValueError("Invalid value for `swap_volume`, must not be `None`")  # noqa: E501

        self._swap_volume = swap_volume

    @property
    def synth_supply(self):
        """Gets the synth_supply of this PoolStatsDetail.  # noqa: E501

        Int64, Synth supply in the pool  # noqa: E501

        :return: The synth_supply of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._synth_supply

    @synth_supply.setter
    def synth_supply(self, synth_supply):
        """Sets the synth_supply of this PoolStatsDetail.

        Int64, Synth supply in the pool  # noqa: E501

        :param synth_supply: The synth_supply of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if synth_supply is None:
            raise ValueError("Invalid value for `synth_supply`, must not be `None`")  # noqa: E501

        self._synth_supply = synth_supply

    @property
    def synth_units(self):
        """Gets the synth_units of this PoolStatsDetail.  # noqa: E501

        Int64, Synth Units in the pool  # noqa: E501

        :return: The synth_units of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._synth_units

    @synth_units.setter
    def synth_units(self, synth_units):
        """Sets the synth_units of this PoolStatsDetail.

        Int64, Synth Units in the pool  # noqa: E501

        :param synth_units: The synth_units of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if synth_units is None:
            raise ValueError("Invalid value for `synth_units`, must not be `None`")  # noqa: E501

        self._synth_units = synth_units

    @property
    def to_asset_average_slip(self):
        """Gets the to_asset_average_slip of this PoolStatsDetail.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), same as history/swaps:toAssetAverageSlip   # noqa: E501

        :return: The to_asset_average_slip of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_average_slip

    @to_asset_average_slip.setter
    def to_asset_average_slip(self, to_asset_average_slip):
        """Sets the to_asset_average_slip of this PoolStatsDetail.

        Float64 (Basis points, 0-10000, where 10000=100%), same as history/swaps:toAssetAverageSlip   # noqa: E501

        :param to_asset_average_slip: The to_asset_average_slip of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_asset_average_slip is None:
            raise ValueError("Invalid value for `to_asset_average_slip`, must not be `None`")  # noqa: E501

        self._to_asset_average_slip = to_asset_average_slip

    @property
    def to_asset_count(self):
        """Gets the to_asset_count of this PoolStatsDetail.  # noqa: E501

        Int64, same as history/swaps:toAssetCount  # noqa: E501

        :return: The to_asset_count of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_count

    @to_asset_count.setter
    def to_asset_count(self, to_asset_count):
        """Sets the to_asset_count of this PoolStatsDetail.

        Int64, same as history/swaps:toAssetCount  # noqa: E501

        :param to_asset_count: The to_asset_count of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_asset_count is None:
            raise ValueError("Invalid value for `to_asset_count`, must not be `None`")  # noqa: E501

        self._to_asset_count = to_asset_count

    @property
    def to_asset_fees(self):
        """Gets the to_asset_fees of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/swaps:toAssetFees  # noqa: E501

        :return: The to_asset_fees of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_fees

    @to_asset_fees.setter
    def to_asset_fees(self, to_asset_fees):
        """Sets the to_asset_fees of this PoolStatsDetail.

        Int64(e8), same as history/swaps:toAssetFees  # noqa: E501

        :param to_asset_fees: The to_asset_fees of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_asset_fees is None:
            raise ValueError("Invalid value for `to_asset_fees`, must not be `None`")  # noqa: E501

        self._to_asset_fees = to_asset_fees

    @property
    def to_asset_volume(self):
        """Gets the to_asset_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/swaps:toAssetVolume  # noqa: E501

        :return: The to_asset_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_volume

    @to_asset_volume.setter
    def to_asset_volume(self, to_asset_volume):
        """Sets the to_asset_volume of this PoolStatsDetail.

        Int64(e8), same as history/swaps:toAssetVolume  # noqa: E501

        :param to_asset_volume: The to_asset_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_asset_volume is None:
            raise ValueError("Invalid value for `to_asset_volume`, must not be `None`")  # noqa: E501

        self._to_asset_volume = to_asset_volume

    @property
    def to_rune_average_slip(self):
        """Gets the to_rune_average_slip of this PoolStatsDetail.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), same as history/swaps:toRuneAverageSlip   # noqa: E501

        :return: The to_rune_average_slip of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_average_slip

    @to_rune_average_slip.setter
    def to_rune_average_slip(self, to_rune_average_slip):
        """Sets the to_rune_average_slip of this PoolStatsDetail.

        Float64 (Basis points, 0-10000, where 10000=100%), same as history/swaps:toRuneAverageSlip   # noqa: E501

        :param to_rune_average_slip: The to_rune_average_slip of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_rune_average_slip is None:
            raise ValueError("Invalid value for `to_rune_average_slip`, must not be `None`")  # noqa: E501

        self._to_rune_average_slip = to_rune_average_slip

    @property
    def to_rune_count(self):
        """Gets the to_rune_count of this PoolStatsDetail.  # noqa: E501

        Int64, same as history/swaps:toRuneCount  # noqa: E501

        :return: The to_rune_count of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_count

    @to_rune_count.setter
    def to_rune_count(self, to_rune_count):
        """Sets the to_rune_count of this PoolStatsDetail.

        Int64, same as history/swaps:toRuneCount  # noqa: E501

        :param to_rune_count: The to_rune_count of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_rune_count is None:
            raise ValueError("Invalid value for `to_rune_count`, must not be `None`")  # noqa: E501

        self._to_rune_count = to_rune_count

    @property
    def to_rune_fees(self):
        """Gets the to_rune_fees of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/swaps:toRuneFees  # noqa: E501

        :return: The to_rune_fees of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_fees

    @to_rune_fees.setter
    def to_rune_fees(self, to_rune_fees):
        """Sets the to_rune_fees of this PoolStatsDetail.

        Int64(e8), same as history/swaps:toRuneFees  # noqa: E501

        :param to_rune_fees: The to_rune_fees of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_rune_fees is None:
            raise ValueError("Invalid value for `to_rune_fees`, must not be `None`")  # noqa: E501

        self._to_rune_fees = to_rune_fees

    @property
    def to_rune_volume(self):
        """Gets the to_rune_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/swaps:toRuneVolume  # noqa: E501

        :return: The to_rune_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_volume

    @to_rune_volume.setter
    def to_rune_volume(self, to_rune_volume):
        """Sets the to_rune_volume of this PoolStatsDetail.

        Int64(e8), same as history/swaps:toRuneVolume  # noqa: E501

        :param to_rune_volume: The to_rune_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if to_rune_volume is None:
            raise ValueError("Invalid value for `to_rune_volume`, must not be `None`")  # noqa: E501

        self._to_rune_volume = to_rune_volume

    @property
    def total_fees(self):
        """Gets the total_fees of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/swaps:totalFees  # noqa: E501

        :return: The total_fees of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._total_fees

    @total_fees.setter
    def total_fees(self, total_fees):
        """Sets the total_fees of this PoolStatsDetail.

        Int64(e8), same as history/swaps:totalFees  # noqa: E501

        :param total_fees: The total_fees of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if total_fees is None:
            raise ValueError("Invalid value for `total_fees`, must not be `None`")  # noqa: E501

        self._total_fees = total_fees

    @property
    def unique_member_count(self):
        """Gets the unique_member_count of this PoolStatsDetail.  # noqa: E501

        Int64, same as len(history/members?pool=POOL)  # noqa: E501

        :return: The unique_member_count of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._unique_member_count

    @unique_member_count.setter
    def unique_member_count(self, unique_member_count):
        """Sets the unique_member_count of this PoolStatsDetail.

        Int64, same as len(history/members?pool=POOL)  # noqa: E501

        :param unique_member_count: The unique_member_count of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if unique_member_count is None:
            raise ValueError("Invalid value for `unique_member_count`, must not be `None`")  # noqa: E501

        self._unique_member_count = unique_member_count

    @property
    def unique_swapper_count(self):
        """Gets the unique_swapper_count of this PoolStatsDetail.  # noqa: E501

        Deprecated, it's always 0.  # noqa: E501

        :return: The unique_swapper_count of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._unique_swapper_count

    @unique_swapper_count.setter
    def unique_swapper_count(self, unique_swapper_count):
        """Sets the unique_swapper_count of this PoolStatsDetail.

        Deprecated, it's always 0.  # noqa: E501

        :param unique_swapper_count: The unique_swapper_count of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if unique_swapper_count is None:
            raise ValueError("Invalid value for `unique_swapper_count`, must not be `None`")  # noqa: E501

        self._unique_swapper_count = unique_swapper_count

    @property
    def units(self):
        """Gets the units of this PoolStatsDetail.  # noqa: E501

        Int64, Total Units (synthUnits + liquidityUnits) in the pool  # noqa: E501

        :return: The units of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this PoolStatsDetail.

        Int64, Total Units (synthUnits + liquidityUnits) in the pool  # noqa: E501

        :param units: The units of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    @property
    def withdraw_asset_volume(self):
        """Gets the withdraw_asset_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/liquidity_changes:withdrawAssetVolume  # noqa: E501

        :return: The withdraw_asset_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_asset_volume

    @withdraw_asset_volume.setter
    def withdraw_asset_volume(self, withdraw_asset_volume):
        """Sets the withdraw_asset_volume of this PoolStatsDetail.

        Int64(e8), same as history/liquidity_changes:withdrawAssetVolume  # noqa: E501

        :param withdraw_asset_volume: The withdraw_asset_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if withdraw_asset_volume is None:
            raise ValueError("Invalid value for `withdraw_asset_volume`, must not be `None`")  # noqa: E501

        self._withdraw_asset_volume = withdraw_asset_volume

    @property
    def withdraw_count(self):
        """Gets the withdraw_count of this PoolStatsDetail.  # noqa: E501

        Int64, same as history/liquidity_changes:withdrawCount  # noqa: E501

        :return: The withdraw_count of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_count

    @withdraw_count.setter
    def withdraw_count(self, withdraw_count):
        """Sets the withdraw_count of this PoolStatsDetail.

        Int64, same as history/liquidity_changes:withdrawCount  # noqa: E501

        :param withdraw_count: The withdraw_count of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if withdraw_count is None:
            raise ValueError("Invalid value for `withdraw_count`, must not be `None`")  # noqa: E501

        self._withdraw_count = withdraw_count

    @property
    def withdraw_rune_volume(self):
        """Gets the withdraw_rune_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/liquidity_changes:withdrawRuneVolume  # noqa: E501

        :return: The withdraw_rune_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_rune_volume

    @withdraw_rune_volume.setter
    def withdraw_rune_volume(self, withdraw_rune_volume):
        """Sets the withdraw_rune_volume of this PoolStatsDetail.

        Int64(e8), same as history/liquidity_changes:withdrawRuneVolume  # noqa: E501

        :param withdraw_rune_volume: The withdraw_rune_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if withdraw_rune_volume is None:
            raise ValueError("Invalid value for `withdraw_rune_volume`, must not be `None`")  # noqa: E501

        self._withdraw_rune_volume = withdraw_rune_volume

    @property
    def withdraw_volume(self):
        """Gets the withdraw_volume of this PoolStatsDetail.  # noqa: E501

        Int64(e8), same as history/liquidity_changes:withdrawVolume  # noqa: E501

        :return: The withdraw_volume of this PoolStatsDetail.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_volume

    @withdraw_volume.setter
    def withdraw_volume(self, withdraw_volume):
        """Sets the withdraw_volume of this PoolStatsDetail.

        Int64(e8), same as history/liquidity_changes:withdrawVolume  # noqa: E501

        :param withdraw_volume: The withdraw_volume of this PoolStatsDetail.  # noqa: E501
        :type: str
        """
        if withdraw_volume is None:
            raise ValueError("Invalid value for `withdraw_volume`, must not be `None`")  # noqa: E501

        self._withdraw_volume = withdraw_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PoolStatsDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PoolStatsDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from xchainpy2_midgard.api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_actions(self, **kwargs):  # noqa: E501
        """Actions List  # noqa: E501

        List actions along with their related transactions. An action is generated by one or more inbound transactions with the intended action set in the transaction memo. The action may result in one or more outbound transactions. Results are paginated by sets of 50. Filters may be applied to query actions.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_actions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Comma separated list. Address of sender or recipient of any in/out transaction related to the action. 
        :param str txid: ID of any in/out tx related to the action
        :param str asset: Comma separated list. Any asset that is part of the action (CHAIN.SYMBOL) Additionally, synth, nosynth, and norune filters can be used for swap, add/withdraw actions. 
        :param str type: One or more comma separated unique types of action (swap, addLiquidity, withdraw, donate, refund, switch) 
        :param str affiliate: Comma separated list. Affiliate address of the action (swap, refund) 
        :param int limit: number of actions returned, default is 50
        :param int offset: pagination offset, default is 0
        :param int next_page_token: if this is given, the actions for the next page will be given
        :param int timestamp: if this is given, the actions older than the timestamp will be given
        :param int height: if this is given, the actions older than the height will be given
        :param int prev_page_token: if this is given, the actions for the previous page will be given
        :param int from_timestamp: if this is given, the actions newer than the timestamp will be given
        :param int from_height: if this is given, the actions newer than the height will be given
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_actions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_actions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_actions_with_http_info(self, **kwargs):  # noqa: E501
        """Actions List  # noqa: E501

        List actions along with their related transactions. An action is generated by one or more inbound transactions with the intended action set in the transaction memo. The action may result in one or more outbound transactions. Results are paginated by sets of 50. Filters may be applied to query actions.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_actions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Comma separated list. Address of sender or recipient of any in/out transaction related to the action. 
        :param str txid: ID of any in/out tx related to the action
        :param str asset: Comma separated list. Any asset that is part of the action (CHAIN.SYMBOL) Additionally, synth, nosynth, and norune filters can be used for swap, add/withdraw actions. 
        :param str type: One or more comma separated unique types of action (swap, addLiquidity, withdraw, donate, refund, switch) 
        :param str affiliate: Comma separated list. Affiliate address of the action (swap, refund) 
        :param int limit: number of actions returned, default is 50
        :param int offset: pagination offset, default is 0
        :param int next_page_token: if this is given, the actions for the next page will be given
        :param int timestamp: if this is given, the actions older than the timestamp will be given
        :param int height: if this is given, the actions older than the height will be given
        :param int prev_page_token: if this is given, the actions for the previous page will be given
        :param int from_timestamp: if this is given, the actions newer than the timestamp will be given
        :param int from_height: if this is given, the actions newer than the height will be given
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address', 'txid', 'asset', 'type', 'affiliate', 'limit', 'offset', 'next_page_token', 'timestamp', 'height', 'prev_page_token', 'from_timestamp', 'from_height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_actions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'address' in params:
            query_params.append(('address', params['address']))  # noqa: E501
        if 'txid' in params:
            query_params.append(('txid', params['txid']))  # noqa: E501
        if 'asset' in params:
            query_params.append(('asset', params['asset']))  # noqa: E501
        if 'type' in params:
            query_params.append(('type', params['type']))  # noqa: E501
        if 'affiliate' in params:
            query_params.append(('affiliate', params['affiliate']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'next_page_token' in params:
            query_params.append(('nextPageToken', params['next_page_token']))  # noqa: E501
        if 'timestamp' in params:
            query_params.append(('timestamp', params['timestamp']))  # noqa: E501
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501
        if 'prev_page_token' in params:
            query_params.append(('prevPageToken', params['prev_page_token']))  # noqa: E501
        if 'from_timestamp' in params:
            query_params.append(('fromTimestamp', params['from_timestamp']))  # noqa: E501
        if 'from_height' in params:
            query_params.append(('fromHeight', params['from_height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/actions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_balance(self, address, **kwargs):  # noqa: E501
        """Current balance for an address  # noqa: E501

        Returns all coin amounts of the given address at the specified timestamp or height, or at the latest process block if neither is provided. (Only one of timestamp or height can be specified, not both.)  This endpoint is enabled only if the midgard startup config allows it.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_balance(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Rune address. (required)
        :param int timestamp: Unix timestamp as seconds since 1970 (if provided, height must not be provided)
        :param int height: Block height (if provided, timestamp must not be provided)
        :return: Balance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_balance_with_http_info(address, **kwargs)  # noqa: E501
        else:
            (data) = self.get_balance_with_http_info(address, **kwargs)  # noqa: E501
            return data

    def get_balance_with_http_info(self, address, **kwargs):  # noqa: E501
        """Current balance for an address  # noqa: E501

        Returns all coin amounts of the given address at the specified timestamp or height, or at the latest process block if neither is provided. (Only one of timestamp or height can be specified, not both.)  This endpoint is enabled only if the midgard startup config allows it.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_balance_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Rune address. (required)
        :param int timestamp: Unix timestamp as seconds since 1970 (if provided, height must not be provided)
        :param int height: Block height (if provided, timestamp must not be provided)
        :return: Balance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address', 'timestamp', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_balance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'address' is set
        if ('address' not in params or
                params['address'] is None):
            raise ValueError("Missing the required parameter `address` when calling `get_balance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in params:
            path_params['address'] = params['address']  # noqa: E501

        query_params = []
        if 'timestamp' in params:
            query_params.append(('timestamp', params['timestamp']))  # noqa: E501
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/balance/{address}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Balance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_borrower_detail(self, address, **kwargs):  # noqa: E501
        """Borrower Details  # noqa: E501

        Returns an array of statistics for all the open loans associated with a given borrower address.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_borrower_detail(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match borrower, an asset address is given. Query can also be multiple addresses should be seperated by comma (',')  (required)
        :return: BorrowerDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_borrower_detail_with_http_info(address, **kwargs)  # noqa: E501
        else:
            (data) = self.get_borrower_detail_with_http_info(address, **kwargs)  # noqa: E501
            return data

    def get_borrower_detail_with_http_info(self, address, **kwargs):  # noqa: E501
        """Borrower Details  # noqa: E501

        Returns an array of statistics for all the open loans associated with a given borrower address.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_borrower_detail_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match borrower, an asset address is given. Query can also be multiple addresses should be seperated by comma (',')  (required)
        :return: BorrowerDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_borrower_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'address' is set
        if ('address' not in params or
                params['address'] is None):
            raise ValueError("Missing the required parameter `address` when calling `get_borrower_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in params:
            path_params['address'] = params['address']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/borrower/{address}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BorrowerDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_borrowers_addresses(self, **kwargs):  # noqa: E501
        """Borrowers List  # noqa: E501

        Returns an array containing the addresses for all borrowers. Addresses are only shown once.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_borrowers_addresses(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: Return only borrowers getting loan against this asset as collateral.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_borrowers_addresses_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_borrowers_addresses_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_borrowers_addresses_with_http_info(self, **kwargs):  # noqa: E501
        """Borrowers List  # noqa: E501

        Returns an array containing the addresses for all borrowers. Addresses are only shown once.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_borrowers_addresses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: Return only borrowers getting loan against this asset as collateral.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_borrowers_addresses" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'asset' in params:
            query_params.append(('asset', params['asset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/borrowers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_churns(self, **kwargs):  # noqa: E501
        """Churns List  # noqa: E501

        Returns block height and timestamp for each churn.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_churns(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[ChurnItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_churns_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_churns_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_churns_with_http_info(self, **kwargs):  # noqa: E501
        """Churns List  # noqa: E501

        Returns block height and timestamp for each churn.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_churns_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[ChurnItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_churns" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/churns', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ChurnItem]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_depth_history(self, pool, **kwargs):  # noqa: E501
        """Depth and Price History  # noqa: E501

        Returns the asset and rune depths and price. The values report the state at the end of each interval.  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_depth_history(pool, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return stats for this single pool. (required)
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: DepthHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_depth_history_with_http_info(pool, **kwargs)  # noqa: E501
        else:
            (data) = self.get_depth_history_with_http_info(pool, **kwargs)  # noqa: E501
            return data

    def get_depth_history_with_http_info(self, pool, **kwargs):  # noqa: E501
        """Depth and Price History  # noqa: E501

        Returns the asset and rune depths and price. The values report the state at the end of each interval.  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_depth_history_with_http_info(pool, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return stats for this single pool. (required)
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: DepthHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pool', 'interval', 'count', 'to', '_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_depth_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'pool' is set
        if ('pool' not in params or
                params['pool'] is None):
            raise ValueError("Missing the required parameter `pool` when calling `get_depth_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'pool' in params:
            path_params['pool'] = params['pool']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/history/depths/{pool}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DepthHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_earnings_history(self, **kwargs):  # noqa: E501
        """Earnings History  # noqa: E501

        Returns earnings data for the specified interval.  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_earnings_history(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: EarningsHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_earnings_history_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_earnings_history_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_earnings_history_with_http_info(self, **kwargs):  # noqa: E501
        """Earnings History  # noqa: E501

        Returns earnings data for the specified interval.  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_earnings_history_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: EarningsHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['interval', 'count', 'to', '_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_earnings_history" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/history/earnings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EarningsHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_health(self, **kwargs):  # noqa: E501
        """Health Info  # noqa: E501

        Returns an object containing the health response of the API. Meaning of heights:  lastThorNode - Latest block as reported by ThorNode.  lastFetched - Latest block fetched from ThorNode.  lastCommitted - Latest block committed to the DB but not fully processed yet.  lastAggregated - Latest block fully processed and aggregated.  genesisInfo - The genesis height Midgard bootstrapped with.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_health(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Health
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_health_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_health_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_health_with_http_info(self, **kwargs):  # noqa: E501
        """Health Info  # noqa: E501

        Returns an object containing the health response of the API. Meaning of heights:  lastThorNode - Latest block as reported by ThorNode.  lastFetched - Latest block fetched from ThorNode.  lastCommitted - Latest block committed to the DB but not fully processed yet.  lastAggregated - Latest block fully processed and aggregated.  genesisInfo - The genesis height Midgard bootstrapped with.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_health_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Health
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_health" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/health', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Health',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_known_pools(self, **kwargs):  # noqa: E501
        """Known Pools List  # noqa: E501

        Returns an object with known pools and their statuses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_known_pools(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: KnownPools
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_known_pools_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_known_pools_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_known_pools_with_http_info(self, **kwargs):  # noqa: E501
        """Known Pools List  # noqa: E501

        Returns an object with known pools and their statuses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_known_pools_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: KnownPools
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_known_pools" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/knownpools', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='KnownPools',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_liquidity_history(self, **kwargs):  # noqa: E501
        """Liquidity Changes History  # noqa: E501

        Returns withdrawals and deposits for given time interval. If pool is not specified returns for all pools  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_liquidity_history(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return stats for given pool. Returns sum of all pools if missing
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400]
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now 
        :param int _from: Start time of the query as unix timestamp
        :return: LiquidityHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_liquidity_history_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_liquidity_history_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_liquidity_history_with_http_info(self, **kwargs):  # noqa: E501
        """Liquidity Changes History  # noqa: E501

        Returns withdrawals and deposits for given time interval. If pool is not specified returns for all pools  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_liquidity_history_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return stats for given pool. Returns sum of all pools if missing
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400]
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now 
        :param int _from: Start time of the query as unix timestamp
        :return: LiquidityHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pool', 'interval', 'count', 'to', '_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_liquidity_history" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pool' in params:
            query_params.append(('pool', params['pool']))  # noqa: E501
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/history/liquidity_changes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LiquidityHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_member_detail(self, address, **kwargs):  # noqa: E501
        """Member Details  # noqa: E501

        Returns an array of statistics for all the liquidity providers associated with a given member address.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_member_detail(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match liquidity providers. Either a rune or an asset address may be given. Query can also be multiple addresses should be seperated by comma (',')  (required)
        :param bool show_savers: A flag to show saver vault membership details, the default is false. 
        :return: MemberDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_member_detail_with_http_info(address, **kwargs)  # noqa: E501
        else:
            (data) = self.get_member_detail_with_http_info(address, **kwargs)  # noqa: E501
            return data

    def get_member_detail_with_http_info(self, address, **kwargs):  # noqa: E501
        """Member Details  # noqa: E501

        Returns an array of statistics for all the liquidity providers associated with a given member address.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_member_detail_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match liquidity providers. Either a rune or an asset address may be given. Query can also be multiple addresses should be seperated by comma (',')  (required)
        :param bool show_savers: A flag to show saver vault membership details, the default is false. 
        :return: MemberDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address', 'show_savers']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_member_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'address' is set
        if ('address' not in params or
                params['address'] is None):
            raise ValueError("Missing the required parameter `address` when calling `get_member_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in params:
            path_params['address'] = params['address']  # noqa: E501

        query_params = []
        if 'show_savers' in params:
            query_params.append(('showSavers', params['show_savers']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/member/{address}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MemberDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_members_adresses(self, **kwargs):  # noqa: E501
        """Members List  # noqa: E501

        Returns an array containing the addresses for all pool members. Addresses are only shown once. If there's both a RUNE address and an asset address for a member, only the RUNE address will be shown.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_members_adresses(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return only members present in the pool.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_members_adresses_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_members_adresses_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_members_adresses_with_http_info(self, **kwargs):  # noqa: E501
        """Members List  # noqa: E501

        Returns an array containing the addresses for all pool members. Addresses are only shown once. If there's both a RUNE address and an asset address for a member, only the RUNE address will be shown.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_members_adresses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return only members present in the pool.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pool']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_members_adresses" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pool' in params:
            query_params.append(('pool', params['pool']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/members', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_network_data(self, **kwargs):  # noqa: E501
        """Network Data  # noqa: E501

        Returns an object containing Network data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_network_data(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Network
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_network_data_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_network_data_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_network_data_with_http_info(self, **kwargs):  # noqa: E501
        """Network Data  # noqa: E501

        Returns an object containing Network data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_network_data_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Network
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_network_data" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/network', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Network',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_nodes(self, **kwargs):  # noqa: E501
        """Nodes List  # noqa: E501

        Returns a list of Node public keys and adresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nodes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Node]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_nodes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_nodes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_nodes_with_http_info(self, **kwargs):  # noqa: E501
        """Nodes List  # noqa: E501

        Returns a list of Node public keys and adresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nodes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[Node]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_nodes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/nodes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Node]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pool(self, asset, **kwargs):  # noqa: E501
        """Details of a Pool  # noqa: E501

        Returns details of the pool: depths, price, 24h volume, APY.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool(asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: pool name (required)
        :param str period: Specifies the base interval from which APY is extrapolated. Default is 14d. 
        :return: PoolDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pool_with_http_info(asset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_pool_with_http_info(asset, **kwargs)  # noqa: E501
            return data

    def get_pool_with_http_info(self, asset, **kwargs):  # noqa: E501
        """Details of a Pool  # noqa: E501

        Returns details of the pool: depths, price, 24h volume, APY.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool_with_http_info(asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: pool name (required)
        :param str period: Specifies the base interval from which APY is extrapolated. Default is 14d. 
        :return: PoolDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset', 'period']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pool" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset' is set
        if ('asset' not in params or
                params['asset'] is None):
            raise ValueError("Missing the required parameter `asset` when calling `get_pool`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset' in params:
            path_params['asset'] = params['asset']  # noqa: E501

        query_params = []
        if 'period' in params:
            query_params.append(('period', params['period']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/pool/{asset}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PoolDetail',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pool_stats(self, asset, **kwargs):  # noqa: E501
        """Pool Statistics  # noqa: E501

        Statistics about the pool. The description of the fields have pointers about the corresponding v2/history location. Visit the history endpoint for drilldowns.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool_stats(asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: pool name (required)
        :param str period: Restricts aggregation type fields to the last period only. Default is 14d. 
        :return: PoolStatsDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pool_stats_with_http_info(asset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_pool_stats_with_http_info(asset, **kwargs)  # noqa: E501
            return data

    def get_pool_stats_with_http_info(self, asset, **kwargs):  # noqa: E501
        """Pool Statistics  # noqa: E501

        Statistics about the pool. The description of the fields have pointers about the corresponding v2/history location. Visit the history endpoint for drilldowns.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool_stats_with_http_info(asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: pool name (required)
        :param str period: Restricts aggregation type fields to the last period only. Default is 14d. 
        :return: PoolStatsDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset', 'period']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pool_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset' is set
        if ('asset' not in params or
                params['asset'] is None):
            raise ValueError("Missing the required parameter `asset` when calling `get_pool_stats`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset' in params:
            path_params['asset'] = params['asset']  # noqa: E501

        query_params = []
        if 'period' in params:
            query_params.append(('period', params['period']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/pool/{asset}/stats', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PoolStatsDetail',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pools(self, **kwargs):  # noqa: E501
        """Pools List  # noqa: E501

        Returns an array containing details for a set of pools  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pools(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status: Filter for only pools with this status
        :param str period: Specifies the base interval from which annualPercentageRate and poolAPY is extrapolated. Default is 14d. 
        :return: list[PoolDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pools_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_pools_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_pools_with_http_info(self, **kwargs):  # noqa: E501
        """Pools List  # noqa: E501

        Returns an array containing details for a set of pools  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pools_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status: Filter for only pools with this status
        :param str period: Specifies the base interval from which annualPercentageRate and poolAPY is extrapolated. Default is 14d. 
        :return: list[PoolDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status', 'period']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pools" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'status' in params:
            query_params.append(('status', params['status']))  # noqa: E501
        if 'period' in params:
            query_params.append(('period', params['period']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/pools', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PoolDetail]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_saver_detail(self, address, **kwargs):  # noqa: E501
        """Saver Details  # noqa: E501

        Returns an array of statistics for all the savers associated with a given member address. Query can also be multiple addresses should be seperated by comma (',')   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_saver_detail(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match the saver. an asset address should be given.  (required)
        :return: SaverDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_saver_detail_with_http_info(address, **kwargs)  # noqa: E501
        else:
            (data) = self.get_saver_detail_with_http_info(address, **kwargs)  # noqa: E501
            return data

    def get_saver_detail_with_http_info(self, address, **kwargs):  # noqa: E501
        """Saver Details  # noqa: E501

        Returns an array of statistics for all the savers associated with a given member address. Query can also be multiple addresses should be seperated by comma (',')   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_saver_detail_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match the saver. an asset address should be given.  (required)
        :return: SaverDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_saver_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'address' is set
        if ('address' not in params or
                params['address'] is None):
            raise ValueError("Missing the required parameter `address` when calling `get_saver_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in params:
            path_params['address'] = params['address']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/saver/{address}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SaverDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_savers_history(self, pool, **kwargs):  # noqa: E501
        """Savers Units and Depth History  # noqa: E501

        Returns savers depths and units. The values report the state at the end of each interval.  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_savers_history(pool, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return stats for this single pool. (required)
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: SaversHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_savers_history_with_http_info(pool, **kwargs)  # noqa: E501
        else:
            (data) = self.get_savers_history_with_http_info(pool, **kwargs)  # noqa: E501
            return data

    def get_savers_history_with_http_info(self, pool, **kwargs):  # noqa: E501
        """Savers Units and Depth History  # noqa: E501

        Returns savers depths and units. The values report the state at the end of each interval.  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_savers_history_with_http_info(pool, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return stats for this single pool. (required)
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: SaversHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pool', 'interval', 'count', 'to', '_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_savers_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'pool' is set
        if ('pool' not in params or
                params['pool'] is None):
            raise ValueError("Missing the required parameter `pool` when calling `get_savers_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'pool' in params:
            path_params['pool'] = params['pool']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/history/savers/{pool}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SaversHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_stats(self, **kwargs):  # noqa: E501
        """Global Stats  # noqa: E501

        Returns an object containing global stats for all pools and all transactions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_stats(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: StatsData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_stats_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_stats_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_stats_with_http_info(self, **kwargs):  # noqa: E501
        """Global Stats  # noqa: E501

        Returns an object containing global stats for all pools and all transactions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_stats_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: StatsData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_stats" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/stats', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatsData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_swap_history(self, **kwargs):  # noqa: E501
        """Swaps History  # noqa: E501

        Returns swap count, volume, fees, slip in specified interval. If pool is not specified returns for all pools  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_swap_history(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return history given pool. Returns sum of all pools if missing.
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: SwapHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_swap_history_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_swap_history_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_swap_history_with_http_info(self, **kwargs):  # noqa: E501
        """Swaps History  # noqa: E501

        Returns swap count, volume, fees, slip in specified interval. If pool is not specified returns for all pools  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.   * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_swap_history_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool: Return history given pool. Returns sum of all pools if missing.
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: SwapHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pool', 'interval', 'count', 'to', '_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_swap_history" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pool' in params:
            query_params.append(('pool', params['pool']))  # noqa: E501
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/history/swaps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SwapHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_thor_name_detail(self, name, **kwargs):  # noqa: E501
        """THORName Details  # noqa: E501

        Returns an array of chains and their addresses associated with the given THORName  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thor_name_detail(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: a THORName (required)
        :return: THORNameDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_thor_name_detail_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_thor_name_detail_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_thor_name_detail_with_http_info(self, name, **kwargs):  # noqa: E501
        """THORName Details  # noqa: E501

        Returns an array of chains and their addresses associated with the given THORName  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thor_name_detail_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: a THORName (required)
        :return: THORNameDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_thor_name_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_thor_name_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/thorname/lookup/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='THORNameDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_thor_names_by_address(self, address, **kwargs):  # noqa: E501
        """Gives a list of THORNames by reverse lookup  # noqa: E501

        Returns an array of THORNames associated with the given address  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thor_names_by_address(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match THORNames against. (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_thor_names_by_address_with_http_info(address, **kwargs)  # noqa: E501
        else:
            (data) = self.get_thor_names_by_address_with_http_info(address, **kwargs)  # noqa: E501
            return data

    def get_thor_names_by_address_with_http_info(self, address, **kwargs):  # noqa: E501
        """Gives a list of THORNames by reverse lookup  # noqa: E501

        Returns an array of THORNames associated with the given address  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thor_names_by_address_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address to match THORNames against. (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_thor_names_by_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'address' is set
        if ('address' not in params or
                params['address'] is None):
            raise ValueError("Missing the required parameter `address` when calling `get_thor_names_by_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in params:
            path_params['address'] = params['address']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/thorname/rlookup/{address}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_thor_names_owner_by_address(self, address, **kwargs):  # noqa: E501
        """THORName owner  # noqa: E501

        Returns an array of THORNames owned by the address. The address is not necessarily an associated address for those thornames.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thor_names_owner_by_address(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address which owns a THORName. (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_thor_names_owner_by_address_with_http_info(address, **kwargs)  # noqa: E501
        else:
            (data) = self.get_thor_names_owner_by_address_with_http_info(address, **kwargs)  # noqa: E501
            return data

    def get_thor_names_owner_by_address_with_http_info(self, address, **kwargs):  # noqa: E501
        """THORName owner  # noqa: E501

        Returns an array of THORNames owned by the address. The address is not necessarily an associated address for those thornames.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thor_names_owner_by_address_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: Address which owns a THORName. (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_thor_names_owner_by_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'address' is set
        if ('address' not in params or
                params['address'] is None):
            raise ValueError("Missing the required parameter `address` when calling `get_thor_names_owner_by_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in params:
            path_params['address'] = params['address']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/thorname/owner/{address}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tvl_history(self, **kwargs):  # noqa: E501
        """Total Value Locked History  # noqa: E501

        Returns total pool depths, total bonds, and total value locked in specified interval.  Total Value Locked = Total Bonds + 2 * Total Pool Depths  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.  * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tvl_history(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: TVLHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tvl_history_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_tvl_history_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_tvl_history_with_http_info(self, **kwargs):  # noqa: E501
        """Total Value Locked History  # noqa: E501

        Returns total pool depths, total bonds, and total value locked in specified interval.  Total Value Locked = Total Bonds + 2 * Total Pool Depths  History endpoint has two modes: * With Interval parameter it returns a series of time buckets. From and To dates will   be rounded to the Interval boundaries. * Without Interval parameter a single From..To search is performed with exact timestamps.  * Interval: possible values: 5min, hour, day, week, month, quarter, year. * count: [1..400]. Defines number of intervals. Don't provide if Interval is missing. * from/to: optional int, unix second.  Possible usages with interval. * last 10 days: `?interval=day&count=10` * last 10 days before to: `?interval=day&count=10&to=1608825600` * next 10 days after from: `?interval=day&count=10&from=1606780800` * Days between from and to. From defaults to start of chain, to defaults to now.   Only the first 400 intervals are returned:   `interval=day&from=1606780800&to=1608825600`  Pagination is possible with from&count and then using the returned meta.endTime as the From parameter of the next query.  Possible configurations without interval: * exact search for one time frame: `?from=1606780899&to=1608825600` * one time frame until now: `?from=1606780899` * from chain start until now: no query parameters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tvl_history_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str interval: Interval of calculations
        :param int count: Number of intervals to return. Should be between [1..400].
        :param int to: End time of the query as unix timestamp. If only count is given, defaults to now. 
        :param int _from: Start time of the query as unix timestamp
        :return: TVLHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['interval', 'count', 'to', '_from']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tvl_history" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/history/tvl', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TVLHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BorrowerPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'collateral_asset': 'str',
        'collateral_deposited': 'str',
        'collateral_withdrawn': 'str',
        'debt_issued_tor': 'str',
        'debt_repaid_tor': 'str',
        'last_open_loan_timestamp': 'str',
        'last_repay_loan_timestamp': 'str',
        'target_assets': 'list[str]'
    }

    attribute_map = {
        'collateral_asset': 'collateral_asset',
        'collateral_deposited': 'collateral_deposited',
        'collateral_withdrawn': 'collateral_withdrawn',
        'debt_issued_tor': 'debt_issued_tor',
        'debt_repaid_tor': 'debt_repaid_tor',
        'last_open_loan_timestamp': 'last_open_loan_timestamp',
        'last_repay_loan_timestamp': 'last_repay_loan_timestamp',
        'target_assets': 'target_assets'
    }

    def __init__(self, collateral_asset=None, collateral_deposited=None, collateral_withdrawn=None, debt_issued_tor=None, debt_repaid_tor=None, last_open_loan_timestamp=None, last_repay_loan_timestamp=None, target_assets=None):  # noqa: E501
        """BorrowerPool - a model defined in Swagger"""  # noqa: E501
        self._collateral_asset = None
        self._collateral_deposited = None
        self._collateral_withdrawn = None
        self._debt_issued_tor = None
        self._debt_repaid_tor = None
        self._last_open_loan_timestamp = None
        self._last_repay_loan_timestamp = None
        self._target_assets = None
        self.discriminator = None
        self.collateral_asset = collateral_asset
        self.collateral_deposited = collateral_deposited
        self.collateral_withdrawn = collateral_withdrawn
        self.debt_issued_tor = debt_issued_tor
        self.debt_repaid_tor = debt_repaid_tor
        self.last_open_loan_timestamp = last_open_loan_timestamp
        self.last_repay_loan_timestamp = last_repay_loan_timestamp
        self.target_assets = target_assets

    @property
    def collateral_asset(self):
        """Gets the collateral_asset of this BorrowerPool.  # noqa: E501

        The asset that the borrower used as collateral  # noqa: E501

        :return: The collateral_asset of this BorrowerPool.  # noqa: E501
        :rtype: str
        """
        return self._collateral_asset

    @collateral_asset.setter
    def collateral_asset(self, collateral_asset):
        """Sets the collateral_asset of this BorrowerPool.

        The asset that the borrower used as collateral  # noqa: E501

        :param collateral_asset: The collateral_asset of this BorrowerPool.  # noqa: E501
        :type: str
        """
        if collateral_asset is None:
            raise ValueError("Invalid value for `collateral_asset`, must not be `None`")  # noqa: E501

        self._collateral_asset = collateral_asset

    @property
    def collateral_deposited(self):
        """Gets the collateral_deposited of this BorrowerPool.  # noqa: E501

        Int64(e8), The total amount of collateral that user deposited  # noqa: E501

        :return: The collateral_deposited of this BorrowerPool.  # noqa: E501
        :rtype: str
        """
        return self._collateral_deposited

    @collateral_deposited.setter
    def collateral_deposited(self, collateral_deposited):
        """Sets the collateral_deposited of this BorrowerPool.

        Int64(e8), The total amount of collateral that user deposited  # noqa: E501

        :param collateral_deposited: The collateral_deposited of this BorrowerPool.  # noqa: E501
        :type: str
        """
        if collateral_deposited is None:
            raise ValueError("Invalid value for `collateral_deposited`, must not be `None`")  # noqa: E501

        self._collateral_deposited = collateral_deposited

    @property
    def collateral_withdrawn(self):
        """Gets the collateral_withdrawn of this BorrowerPool.  # noqa: E501

        Int64(e8), The total amount of collateral the system paid back to the user  # noqa: E501

        :return: The collateral_withdrawn of this BorrowerPool.  # noqa: E501
        :rtype: str
        """
        return self._collateral_withdrawn

    @collateral_withdrawn.setter
    def collateral_withdrawn(self, collateral_withdrawn):
        """Sets the collateral_withdrawn of this BorrowerPool.

        Int64(e8), The total amount of collateral the system paid back to the user  # noqa: E501

        :param collateral_withdrawn: The collateral_withdrawn of this BorrowerPool.  # noqa: E501
        :type: str
        """
        if collateral_withdrawn is None:
            raise ValueError("Invalid value for `collateral_withdrawn`, must not be `None`")  # noqa: E501

        self._collateral_withdrawn = collateral_withdrawn

    @property
    def debt_issued_tor(self):
        """Gets the debt_issued_tor of this BorrowerPool.  # noqa: E501

        Int64(e8), The total amount of debt issued as debt for user. denominated in TOR.  # noqa: E501

        :return: The debt_issued_tor of this BorrowerPool.  # noqa: E501
        :rtype: str
        """
        return self._debt_issued_tor

    @debt_issued_tor.setter
    def debt_issued_tor(self, debt_issued_tor):
        """Sets the debt_issued_tor of this BorrowerPool.

        Int64(e8), The total amount of debt issued as debt for user. denominated in TOR.  # noqa: E501

        :param debt_issued_tor: The debt_issued_tor of this BorrowerPool.  # noqa: E501
        :type: str
        """
        if debt_issued_tor is None:
            raise ValueError("Invalid value for `debt_issued_tor`, must not be `None`")  # noqa: E501

        self._debt_issued_tor = debt_issued_tor

    @property
    def debt_repaid_tor(self):
        """Gets the debt_repaid_tor of this BorrowerPool.  # noqa: E501

        Int64(e8), The total amount of debt that the user paid back. denominated in TOR.  # noqa: E501

        :return: The debt_repaid_tor of this BorrowerPool.  # noqa: E501
        :rtype: str
        """
        return self._debt_repaid_tor

    @debt_repaid_tor.setter
    def debt_repaid_tor(self, debt_repaid_tor):
        """Sets the debt_repaid_tor of this BorrowerPool.

        Int64(e8), The total amount of debt that the user paid back. denominated in TOR.  # noqa: E501

        :param debt_repaid_tor: The debt_repaid_tor of this BorrowerPool.  # noqa: E501
        :type: str
        """
        if debt_repaid_tor is None:
            raise ValueError("Invalid value for `debt_repaid_tor`, must not be `None`")  # noqa: E501

        self._debt_repaid_tor = debt_repaid_tor

    @property
    def last_open_loan_timestamp(self):
        """Gets the last_open_loan_timestamp of this BorrowerPool.  # noqa: E501

        Int64, Unix timestamp for the last time borrower opened a loan  # noqa: E501

        :return: The last_open_loan_timestamp of this BorrowerPool.  # noqa: E501
        :rtype: str
        """
        return self._last_open_loan_timestamp

    @last_open_loan_timestamp.setter
    def last_open_loan_timestamp(self, last_open_loan_timestamp):
        """Sets the last_open_loan_timestamp of this BorrowerPool.

        Int64, Unix timestamp for the last time borrower opened a loan  # noqa: E501

        :param last_open_loan_timestamp: The last_open_loan_timestamp of this BorrowerPool.  # noqa: E501
        :type: str
        """
        if last_open_loan_timestamp is None:
            raise ValueError("Invalid value for `last_open_loan_timestamp`, must not be `None`")  # noqa: E501

        self._last_open_loan_timestamp = last_open_loan_timestamp

    @property
    def last_repay_loan_timestamp(self):
        """Gets the last_repay_loan_timestamp of this BorrowerPool.  # noqa: E501

        Int64, Unix timestamp for the last time borrower repayment occurred  # noqa: E501

        :return: The last_repay_loan_timestamp of this BorrowerPool.  # noqa: E501
        :rtype: str
        """
        return self._last_repay_loan_timestamp

    @last_repay_loan_timestamp.setter
    def last_repay_loan_timestamp(self, last_repay_loan_timestamp):
        """Sets the last_repay_loan_timestamp of this BorrowerPool.

        Int64, Unix timestamp for the last time borrower repayment occurred  # noqa: E501

        :param last_repay_loan_timestamp: The last_repay_loan_timestamp of this BorrowerPool.  # noqa: E501
        :type: str
        """
        if last_repay_loan_timestamp is None:
            raise ValueError("Invalid value for `last_repay_loan_timestamp`, must not be `None`")  # noqa: E501

        self._last_repay_loan_timestamp = last_repay_loan_timestamp

    @property
    def target_assets(self):
        """Gets the target_assets of this BorrowerPool.  # noqa: E501


        :return: The target_assets of this BorrowerPool.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_assets

    @target_assets.setter
    def target_assets(self, target_assets):
        """Sets the target_assets of this BorrowerPool.


        :param target_assets: The target_assets of this BorrowerPool.  # noqa: E501
        :type: list[str]
        """
        if target_assets is None:
            raise ValueError("Invalid value for `target_assets`, must not be `None`")  # noqa: E501

        self._target_assets = target_assets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BorrowerPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BorrowerPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
